"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const path_1 = require("path");
const profiler_1 = require("@tgra/profiler");
const log_1 = require("../utils/log");
const ora_1 = __importDefault(require("ora"));
const chalk_1 = __importDefault(require("chalk"));
commander_1.program
    .command("build")
    .description("Builds a profile")
    .argument("<profile-path>", "the path to the profile to build")
    .option("-v", "--verbose")
    .action(async (profilePath, flags) => {
    const resolvedProfilePath = (0, path_1.resolve)(profilePath);
    const profileParser = new profiler_1.ProfileParser(resolvedProfilePath);
    const profileCompositor = new profiler_1.ProfileCompositor(profileParser, !flags.v);
    const buildOutput = profileParser.profileData.output?.type === "disk" ?
        profileParser.profileData.output.diskDevice :
        ".tegra/tegraBuild.img";
    const profileName = profileParser.profileData.name ?? profilePath;
    const spinner = (0, ora_1.default)({
        text: `${chalk_1.default.yellow("working")} Building "${profileName}" to ${buildOutput}...`
    });
    log_1.log.info(`Initializing Tegra build settings`);
    profileCompositor.init();
    log_1.log.info(`Initialized build settings`);
    spinner.start();
    await profileCompositor.build().catch((err) => {
        spinner.fail(`${chalk_1.default.red("error")} Build failed:\n${err}`);
        process.exit(1);
    }).then(() => {
        spinner.succeed(`${chalk_1.default.green("success")} Build success! Output: ${buildOutput}`);
    });
});
